# A library for remote sensing image pansharpening and enhancement

## The goal is to assemble all the known good methods within one useful python library
The data processing is based on rasterio bindings to GDAL binaries.
Big files are supported via windowed IO.

## Methods:
1. IHS
2. Brovey
3. Generalized IHS for any number of channels
